@@ -1,8 +1,8 @@
 ;;; timu-line.el --- Custom and simple mode line -*- lexical-binding: t; -*-
 
 ;; Author: Aimé Bertrand <aime.bertrand@macowners.club>
-;; Package-Version: 20260121.1910
-;; Package-Revision: 9ba731bd947b
+;; Package-Version: 20260131.1904
+;; Package-Revision: 745f38f27e9b
 ;; Package-Requires: ((emacs "29.1"))
 ;; Created: 2023-07-31
 ;; Keywords: modeline frames ui
@@ -671,30 +671,35 @@ Information:
 
 (defun timu-line-unread-mu4e-count ()
   "Return the count (e.g. \"e:42\") of unread emails as a propertized string.
-This works only with \"mu\" so far.
-
-Also show an indicator (\":u\") when mail index is being updated.
-The display it controlled by `timu-line-show-mu4e-index-update-indicator'."
+This works only with \"mu\" so far."
   (timu-line-face-switcher
    'timu-line-active-face 'timu-line-inactive-face
    (propertize
     (if (executable-find "mu")
-        (let ((mu4e-index-update-indicator
-               (if timu-line-show-mu4e-index-update-indicator
-                   (if timu-line-mu4e-is-updating
-                       ":u"
-                     "")
-                 "")))
-          (concat " e:"
-                  (condition-case nil
-                      ;; TODO - for now catch error when visiting orphaned files
-                      (shell-command-to-string
-                       "printf $(mu find flag:unread 2> /dev/null | wc -l)")
-                    (error "err"))
-                  (format "%s" mu4e-index-update-indicator)))
+        (concat " e:"
+                (condition-case nil
+                    ;; TODO - for now catch error when visiting orphaned files
+                    (shell-command-to-string
+                     "printf $(mu find flag:unread 2> /dev/null | wc -l)")
+                  (error "err")))
       "")
     'face face)))
 
+(defun timu-line-mu4e-update-string ()
+  "Show an indicator (\":u\") when mail index is being updated.
+The display it controlled by `timu-line-show-mu4e-index-update-indicator'.
+This works only with \"mu\" so far."
+  (timu-line-face-switcher
+   'timu-line-status-face 'timu-line-inactive-face
+   (propertize
+    (if (executable-find "mu")
+        (if timu-line-show-mu4e-index-update-indicator
+            (if timu-line-mu4e-is-updating
+                ":u"
+              "")
+          ""))
+    'face face)))
+
 (defun timu-line-tab-number ()
   "Return current tab number & total numbers of tabs as a propertized string."
   (timu-line-face-switcher
@@ -871,6 +876,7 @@ aligned respectively."
                             (timu-line-major-mode)
                             timu-line-spacer-bottom
                             (timu-line-unread-mu4e-count)
+                            (timu-line-mu4e-update-string)
                             (timu-line-tab-number)
                             (timu-line-position)
                             (timu-line-popper-indicator)
